==> kui-web-terminal-container-v2.3.3-6.tar.gz: package/lib/components/FileUploader/FileUploader.Skeleton.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _SkeletonText = _interopRequireDefault(require("../SkeletonText"));

var _Button = _interopRequireDefault(require("../Button/Button.Skeleton"));

var _usePrefix = require("../../internal/usePrefix");

var _excluded = ["className"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function FileUploaderSkeleton(_ref) {
  var className = _ref.className,
      rest = _objectWithoutProperties(_ref, _excluded);

  var prefix = (0, _usePrefix.usePrefix)();
  return /*#__PURE__*/_react.default.createElement("div", _extends({
    className: (0, _classnames.default)("".concat(prefix, "--form-item"), className)
  }, rest), /*#__PURE__*/_react.default.createElement(_SkeletonText.default, {
    heading: true,
    width: "100px"
  }), /*#__PURE__*/_react.default.createElement(_SkeletonText.default, {
    width: "225px",
    className: "".concat(prefix, "--label-description")
  }), /*#__PURE__*/_react.default.createElement(_Button.default, null));
}

FileUploaderSkeleton.propTypes = {
  /**
   * Specify an optional className to add.
   */
  className: _propTypes.default.string
};
var _default = FileUploaderSkeleton;
exports.default = _default;

==> kui-web-terminal-container-v2.3.8-5.tar.gz: package/lib/components/FileUploader/FileUploader.Skeleton.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _SkeletonText = _interopRequireDefault(require("../SkeletonText"));

var _Button = _interopRequireDefault(require("../Button/Button.Skeleton"));

var _usePrefix = require("../../internal/usePrefix");

var _excluded = ["className"];

function FileUploaderSkeleton(_ref) {
  var className = _ref.className,
      rest = (0, _objectWithoutProperties2.default)(_ref, _excluded);
  var prefix = (0, _usePrefix.usePrefix)();
  return /*#__PURE__*/_react.default.createElement("div", (0, _extends2.default)({
    className: (0, _classnames.default)("".concat(prefix, "--form-item"), className)
  }, rest), /*#__PURE__*/_react.default.createElement(_SkeletonText.default, {
    heading: true,
    width: "100px"
  }), /*#__PURE__*/_react.default.createElement(_SkeletonText.default, {
    width: "225px",
    className: "".concat(prefix, "--label-description")
  }), /*#__PURE__*/_react.default.createElement(_Button.default, null));
}

FileUploaderSkeleton.propTypes = {
  /**
   * Specify an optional className to add.
   */
  className: _propTypes.default.string
};
var _default = FileUploaderSkeleton;
exports.default = _default;
